/* ==============================================================================
 * Author:  Jonathan Weaver, jonw0224@aim.com
 * E-mail Contact: jonw0224@aim.com
 * Description:  DLL Wrapper for serial.h, serial.c
 * Version: 3.1
 * Date: 4/25/2014
 * Filename:  dll.h
 *
 * Versions History:
 *                    2/13/2012 -  Created file
 *                    8/29/2012 -  Updated serial.c, serial.h, and added
 *                                 dllimport of setPortTimeouts.
 *                    2/11/2013 -  Modified serialRXChar.  Removed
 *                                 serialRXString and serialTXString.
 *                    3/8/2013  -  Added setPortRTS, setPortDTR
 *                    1/10/2014 -  Added support for multiple COM ports.
 *                    3/13/2014 -  Added serialTXString and serialRXString.
 *                                 Added serialBytesAvailable.
 *                    4/25/2014 -  Fixed unsigned character bug.
 *
 * Copyright (C) 2012-2014 Jonathan Weaver
 *
 * This file is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ==============================================================================
 */

#ifndef _DLL_H_
#define _DLL_H_

#if BUILDING_DLL
# define DLLIMPORT __declspec (dllexport)
#else /* Not BUILDING_DLL */
# define DLLIMPORT __declspec (dllimport)
#endif /* Not BUILDING_DLL */

DLLIMPORT int sPortClose(int hComm);

DLLIMPORT int sPortOpen(char portName[], char configStr[]);

DLLIMPORT int sTXChar(int hComm, unsigned char ch);

DLLIMPORT int sRXChar(int hComm);

/* Sets the port timeouts.
 * rdInterval: the timeout for each byte read in milliseconds
 * rdTotalMult: the multiplier for each byte read
 * rdTotalCosnt: an additional timeout to allow at the end of a recieve in milliseconds
 * wrTotalMult: the multiplier for each byte write
 * wrTotalConst: the additional timeout to allow at the end of transmit in milliseconds
 * returns: 1 if successful, 0 if unsuccessful */
DLLIMPORT int sPortTimeouts(int hComm, int rdInterval, int rdTotalMult, int rdTotalConst, int wrTotalMult, int wrTotalConst);

/* Sets the RTS signal on the comm port
 * rts: 1 to set RTS, 0 to clear RTS
 * returns: nonzero if successful, 0 if unsuccessful */
DLLIMPORT int sPortRTS(int hComm, int rts);

/* Sets the DTR signal on the comm port
 * dtr: 1 to set DTR, 0 to clear DTR
 * returns: nonzero is successful, 0 if unsuccessful */
DLLIMPORT int sPortDTR(int hComm, int dtr);

/* Returns the bytes available in the recieve buffer to be read
 * hComm: then handle to the Comm poet
 * returns: the number of bytes available in the recieve buffer to be read */
DLLIMPORT int sPortBytesAvailable(int hComm);

/* Recieves a string over the serial port
 * hComm: the handle to the Comm Port
 * strToRead: a buffer for the string to recieve
 * noOfBytesToRead: the number of bytes of the string to recieve
 * returns: 0 if failed, number of bytes read if successful
 */
DLLIMPORT int sRXString(int hComm, unsigned char* strToRead, int noOfBytesToRead);

/* Transmits a string over the serial port
 * hComm: the handle to the Comm Port
 * strToWrite: the string to transmit
 * noOfBytesToWrite: the number of bytes of the string to transmit
 * returns: 0 if failed, number of bytes written if successful
 */
DLLIMPORT int sTXString(int hComm, unsigned char strToWrite[], int noOfBytesToWrite);

/* Sets the read and write buffersizes to be used with the serial port
 * hComm: the handle to the Comm Port
 * readSize: the size of the read buffer
 * writeSize: the size of the write buffer */
DLLIMPORT int sSetBufferSize(int hComm, int readSize, int writeSize);

#endif /* _DLL_H_ */
