/* ==============================================================================
 * Author:  Jonathan Weaver, jonw0224@aim.com
 * E-mail Contact: jonw0224@aim.com
 * Description:  DLL Wrapper for serial.h, serial.c
 * Version: 3.1
 * Date: 4/25/2014
 * Filename:  dllmain.c
 *
 * Versions History:
 *                    2/13/2012 -  Created file
 *                    8/29/2012 -  Updated serial.c, serial.h, and added
 *                                 dllimport of setPortTimeouts.
 *                    2/11/2013 -  Modified serialRXChar.  Removed
 *                                 serialRXString and serialTXString.
 *                     3/8/2013 -  Added setPortRTS, setPortDTR
 *                    1/10/2014 -  Added support for multiple COM ports
 *                    3/13/2014 -  Added serialTXString and serialRXString.
 *                                 Added serialBytesAvailable.
 *                    4/25/2014 -  Fixed unsigned character bug.
 *
 * Copyright (C) 2012-2014 Jonathan Weaver
 *
 * This file is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ==============================================================================
 */

#include "dll.h"
#include <windows.h>
#include <stdio.h>
#include <stdlib.h>
#include "serial.h"

DLLIMPORT int sPortClose(int hComm)
{
    return serialPortClose(hComm);
}

DLLIMPORT int sPortOpen(char portName[], char configStr[])
{
    return serialPortOpen(portName, configStr);
}

DLLIMPORT int sTXChar(int hComm, unsigned char ch)
{
    return serialTXChar(hComm, ch);
}

DLLIMPORT int sRXChar(int hComm)
{
    unsigned char ch;
    int a;
    a = serialRXChar(hComm, &ch);
    if(a == 0)
        return -1;
    return ch;
}

DLLIMPORT int sPortTimeouts(int hComm, int rdInterval, int rdTotalMult, int rdTotalConst, int wrTotalMult, int wrTotalConst)
{
    return setPortTimeouts(hComm, rdInterval, rdTotalMult, rdTotalConst, wrTotalMult, wrTotalConst);
}

DLLIMPORT int sPortRTS(int hComm, int rts)
{
    return setPortRTS(hComm, rts);
}

DLLIMPORT int sPortDTR(int hComm, int dtr)
{
    return setPortDTR(hComm, dtr);
}

DLLIMPORT int sPortBytesAvailable(int hComm)
{
	return serialPortBytesAvailable(hComm);
}

DLLIMPORT int sRXString(int hComm, unsigned char* strToRead, int noOfBytesToRead)
{
    return serialRXString(hComm, strToRead, noOfBytesToRead);
}

/* Transmits a string over the serial port
 * hComm: the handle to the Comm Port
 * strToWrite: the string to transmit
 * noOfBytesToWrite: the number of bytes of the string to transmit
 * returns: 0 if failed, number of bytes written if successful
 */
DLLIMPORT int sTXString(int hComm, unsigned char* strToWrite, int noOfBytesToWrite)
{
    return serialTXString(hComm, strToWrite, noOfBytesToWrite);

}

/* Sets the read and write buffersizes to be used with the serial port
 * hComm: the handle to the Comm Port
 * readSize: the size of the read buffer
 * writeSize: the size of the write buffer */
DLLIMPORT int sSetBufferSize(int hComm, int readSize, int writeSize)
{
    return serialSetBufferSize(hComm, readSize, writeSize);
}


BOOL APIENTRY DllMain (HINSTANCE hInst     /* Library instance handle. */ ,
                       DWORD reason        /* Reason this function is being called. */ ,
                       LPVOID reserved     /* Not used. */ )
{
    switch (reason)
    {
      case DLL_PROCESS_ATTACH:
        break;

      case DLL_PROCESS_DETACH:
        break;

      case DLL_THREAD_ATTACH:
        break;

      case DLL_THREAD_DETACH:
        break;
    }

    /* Returns TRUE on success, FALSE on failure */
    return TRUE;
}
