% ==============================================================================
% Author:  Jonathan Weaver, jonw0224@aim.com
% E-mail Contact: jonw0224@aim.com
% Description:  Serial interface 
% Version: 3.1
% Date: 4/25/2014
% Filename:  example.m
%
% Demonstrates the use of the serial interface in FreeMat.  Assumes the TX and
% RX pins are shorted on the serial port.
% ==============================================================================

% Load serial.dll using serialload.m.  As of version 3.1, calling serialload is 
% unnecessary, but it doesn't hurt anything.
serialload;

% Open COM1 at 57600 BAUD, 8 bits with 1 stop bit
port = serialPortOpen('COM1', '57600,n,8,1');

% Set the serial port timeouts to 1 ms per byte
setPortTimeouts(port,1,1,0,1,0);

% Transmit an ASCII character 'a'
serialTXChar(port, 'a');

% Recieve the ASCII character 'a'
cha = serialRXChar(port)

chb = serialRXChar(port)

% You should see cha = 97, since 97 is the ASCII code for 'a'
% You should also see chb = -1, since there wasn't another character available 
% to be recieved.

% Transmit 'Hello World'
serialTXString(port, 'Hello World', 11);

% Wait to ensure the transmit is finished
sleep 1

% Check recieve bytes available, should be 11
byteA = serialPortBytesAvailable(port)

% Recieve 'Hello World'
% Allocate memory to recieve the string, rStr will be an array of ints with the ASCII codes
rStr = zeros(1,11);
serialRXString(port, rStr, 11);
rStr

% View the array as a string
rStrViewable = string(rStr)

% Close COM1
serialPortClose(port);
