% Initializes and opens the serial port
% portName: the name of the comm port to open (e.g. "COM1")
% configString: configuration string for the port including baud rate, etc. (e.g. "57600,n,8,1")
% returns:  handle to the serial port if successful, -1 if port failed to open, -2 if failed to build DCM, -3 if failed to apply DCM to serial port, -4 if failed to set timeouts.
%
% Licensed under the GPL
% Copyright (C) 2014 Jonathan Weaver <jonw0224@aim.com>

function R = serialPortOpen(portName, configStr)
    if(nargin == 2)
        if(isstr(portName) && isstr(configStr))
            try
                R = serialPortOpen_internal(portName, configStr);
            catch
                serialload;
                R = serialPortOpen_internal(portName, configStr);
            end                
        else
            error('portName and configStr should be strings (e.g. serialPortOpen("COM1", "57600,n,8,1"))');
        end
    else
        error('Expecting a two arguments.  Usage: serialPortOpen(portName, configStr).');    
    end
end