% Transmits a string over the serial port
% hComm: the handle to the Comm Port
% strToWrite: the string to transmit
% noOfBytesToWrite: the number of bytes of the string to transmit
% returns: 0 if failed, number of bytes written if successful
%
% Licensed under the GPL
% Copyright (C) 2014 Jonathan Weaver <jonw0224@aim.com>

function R = serialTXString(hComm, strToWrite, noOfBytesToWrite)
    if(nargin == 3)
        if(isscalar(hComm) && isnumeric(hComm) && isscalar(noOfBytesToWrite) && isnumeric(noOfBytesToWrite))
            % Pad with zeros
            if(length(strToWrite) < noOfBytesToWrite)
                strToWrite = [reshape(strToWrite, 1, len(strToWrite)), zeros(1, noOfBytesToWrite - len(strToWrite))];
            end
            try
                R = serialTXString_internal(hComm, strToWrite, noOfBytesToWrite);
            catch
                serialload;
                R = serialTXString_internal(hComm, strToWrite, noOfBytesToWrite);
            end  
        else
            error('Expecting hComm and noOfBytesToWrite to be numeric.');
        end
    else
        error('Expecting three arguments.  Usage: serialRXString(hComm, strToRead, noOfBytesToRead).');
    end
end